summaryrefslogtreecommitdiff
path: root/src/debug/daccess
diff options
context:
space:
mode:
authorDick van den Brink <d_vandenbrink@outlook.com>2015-04-27 00:24:55 +0200
committerDick van den Brink <d_vandenbrink@outlook.com>2015-04-27 00:24:55 +0200
commit75fe12248fec50481b2c8a82f5f4995a5db88dd5 (patch)
tree5a0374389cff8bf72eddcbee343fc2b51cd87603 /src/debug/daccess
parent8a53f74af4170701b809c4454fc54bdf3bc531d3 (diff)
downloadcoreclr-75fe12248fec50481b2c8a82f5f4995a5db88dd5.tar.gz
coreclr-75fe12248fec50481b2c8a82f5f4995a5db88dd5.tar.bz2
coreclr-75fe12248fec50481b2c8a82f5f4995a5db88dd5.zip
Replace hash_map/set with unordered_map/set
hash_map/hash_set are deprecated in VS 2015 fix #821
Diffstat (limited to 'src/debug/daccess')
-rw-r--r--src/debug/daccess/dacimpl.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/debug/daccess/dacimpl.h b/src/debug/daccess/dacimpl.h
index 0499407a74..59839b7987 100644
--- a/src/debug/daccess/dacimpl.h
+++ b/src/debug/daccess/dacimpl.h
@@ -18,7 +18,7 @@
#if defined(_TARGET_ARM_) || defined(FEATURE_CORESYSTEM) // @ARMTODO: STL breaks the build with current VC headers
//---------------------------------------------------------------------------------------
// Setting DAC_HASHTABLE tells the DAC to use the hand rolled hashtable for
// storing code:DAC_INSTANCE . Otherwise, the DAC uses the STL hash_map to.
#define DAC_HASHTABLE
#endif // _TARGET_ARM_|| FEATURE_CORESYSTEM
@@ -26,7 +26,7 @@
#ifndef DAC_HASHTABLE
#pragma push_macro("return")
#undef return
-#include <hash_map>
+#include <unordered_map>
#pragma pop_macro("return")
#endif //DAC_HASHTABLE
extern CRITICAL_SECTION g_dacCritSec;
@@ -784,7 +784,7 @@ private:
HashInstanceKeyBlock* m_hash[DAC_INSTANCE_HASH_SIZE];
#else //DAC_HASHTABLE
// We're going to use the STL hash_map for our instance hash.
// This has the benefit of scaling to different workloads appropriately (as opposed to having a
// fixed number of buckets).
@@ -829,7 +829,7 @@ private:
#endif
};
- typedef stdext::hash_map<TADDR, DAC_INSTANCE*, DacHashCompare > DacInstanceHash;
+ typedef stdext::unordered_map<TADDR, DAC_INSTANCE*, DacHashCompare > DacInstanceHash;
typedef DacInstanceHash::value_type DacInstanceHashValue;
typedef DacInstanceHash::iterator DacInstanceHashIterator;
DacInstanceHash m_hash;
@@ -18,7 +18,7 @@
//---------------------------------------------------------------------------------------
// Setting DAC_HASHTABLE tells the DAC to use the hand rolled hashtable for
-// storing code:DAC_INSTANCE . Otherwise, the DAC uses the STL hash_map to.
+// storing code:DAC_INSTANCE . Otherwise, the DAC uses the STL unordered_map to.
#define DAC_HASHTABLE
#endif // _TARGET_ARM_|| FEATURE_CORESYSTEM
@@ -784,7 +784,7 @@ private:
HashInstanceKeyBlock* m_hash[DAC_INSTANCE_HASH_SIZE];
#else //DAC_HASHTABLE
- // We're going to use the STL hash_map for our instance hash.
+ // We're going to use the STL unordered_map for our instance hash.
// This has the benefit of scaling to different workloads appropriately (as opposed to having a
// fixed number of buckets).